#!/bin/bash
#
# build_gsl.sh <product_dir> <debug|opt|prof> [tar]
# (in source build required)

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> <debug|opt|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir()
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
extraqual=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=gsl
origpkgver=v2_5
pkgver=${origpkgver}
ssibuildshims_version=v1_04_08
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtar=gsl-${pkgdotver}.tar.gz

get_this_dir

get_ssibuildshims

source define_basics NO_BASE_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

if [ "${extraqual}" = "opt" ]
then
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "debug" ]
then
    cxxflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
fi

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi
mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

set -x

cd ${sourcedir}
echo "In code directory: ${PWD}"
tar xf ${tardir}/${pkgtar} || ssi_die "Unable to undwind ${tardir}/${pkgtar}"

cd ${sourcedir}/gsl-${pkgdotver}
patch --verbose -b -p0 < ${patchdir}/gsl.patch || ssi_die "ERROR: patch failed."

cd ${blddir} || ssi_die "Unable to cd to ${blddir}"
config_dir=${sourcedir}/gsl-${pkgdotver}
echo "config_dir is: ${config_dir}"
if [ ! -f ${config_dir}/configure ]; then
  echo "There is no configure script in ${config_dir}"
  exit 1
fi

CFLAGS="${cxxflg}" ${config_dir}/configure --prefix=${pkgdir} --enable-shared --enable-static=no --with-pic
make -j `${SSIBUILDSHIMS_DIR}/bin/ncores` || ssi_die "Failed while building gsl"
## ignore broken make check 
##  make check || ssi_die "Failed running make check"
make install || ssi_die "Failed while installing gsl"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}
echo "${package} is installed at ${GSL_FQ_DIR}"


# need to fix paths in bin/gsl-config

fixfile=/tmp/gslfix$$$$.sh
rm -f $fixfile

echo "#!/bin/bash" > $fixfile
echo "" >>  $fixfile
echo "mv ${GSL_FQ_DIR}/bin/gsl-config ${GSL_FQ_DIR}/bin/gsl-config.bak" >> $fixfile
echo "cat ${GSL_FQ_DIR}/bin/gsl-config.bak | sed 's%${GSL_LIB}%\${GSL_LIB}%'  | sed 's%${GSL_INC}%\${GSL_INC}%'   | sed 's%${GSL_FQ_DIR}%\${GSL_FQ_DIR}%'> ${GSL_FQ_DIR}/bin/gsl-config" >> $fixfile
echo "chmod +x  ${GSL_FQ_DIR}/bin/gsl-config" >> $fixfile
echo "mv ${GSL_FQ_DIR}/lib/pkgconfig/gsl.pc ${GSL_FQ_DIR}/lib/pkgconfig/gsl.pc.bak" >> $fixfile
echo "cat ${GSL_FQ_DIR}/lib/pkgconfig/gsl.pc.bak | sed 's%${GSL_FQ_DIR}%\${GSL_FQ_DIR}%' > ${GSL_FQ_DIR}/lib/pkgconfig/gsl.pc" >> $fixfile
echo "" >>  $fixfile

chmod +x $fixfile
$fixfile
rm -f $fixfile

# remove libtool files since they contain hardwired paths
rm -vf ${GSL_FQ_DIR}/lib/*.la

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
